==> gwasrapidd_0.99.13.tar.gz: gwasrapidd/tests/testthat/mocks/gc/v/rs0/studies.R <==
structure(list(url = "gc/v/rs0/studies", status_code = 404L, 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:49:34 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
            `strict-transport-security` = "max-age=0", date = "Thu, 25 Nov 2021 22:49:34 GMT", 
            `x-application-context` = "application", expires = "0", 
            `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
            `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
            `x-frame-options` = "DENY"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1637880574, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 2.8e-05, 
    connect = 2.8e-05, pretransfer = 6.6e-05, starttransfer = 0.057497, 
    total = 0.057518)), class = "response")

==> gwasrapidd_0.99.17.tar.gz: gwasrapidd/tests/testthat/mocks/gc/v/rs0/studies.R <==
structure(list(url = "gc/v/rs0/studies", status_code = 404L, 
    headers = structure(list(server = "Apache-Coyote/1.1", `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
        `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 13:59:43 GMT", 
        `x-application-context` = "application", expires = "0", 
        `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
        `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
        `x-frame-options` = "DENY"), class = c("insensitive", 
    "list")), all_headers = list(list(status = 404L, version = "HTTP/1.1", 
        headers = structure(list(server = "Apache-Coyote/1.1", 
            `cache-control` = "no-cache, no-store, max-age=0, must-revalidate", 
            `strict-transport-security` = "max-age=0", date = "Sun, 04 Jun 2023 13:59:43 GMT", 
            `x-application-context` = "application", expires = "0", 
            `x-xss-protection` = "1; mode=block", pragma = "no-cache", 
            `transfer-encoding` = "chunked", `x-content-type-options` = "nosniff", 
            `x-frame-options` = "DENY"), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = raw(0), date = structure(1685887183, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 1.8e-05, 
    connect = 0, pretransfer = 5.6e-05, starttransfer = 0.058269, 
    total = 0.058289)), class = "response")
